==> com.liferay.layout.content.page.editor.web-2.0.74.jar: META-INF/resources/page_editor/plugins/fragments-widgets/index.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.74/page_editor/plugins/fragments-widgets/index", ['module', 'exports', 'require', 'frontend-js-react-web$react', '../../core/AppContext', './components/FragmentsSidebar'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports["default"] = void 0;

    var _react = _interopRequireDefault(require("frontend-js-react-web$react"));

    var _AppContext = require("../../core/AppContext");

    var _FragmentsSidebar = _interopRequireDefault(require("./components/FragmentsSidebar"));

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { "default": obj };
    }

    function _classCallCheck(instance, Constructor) {
      if (!(instance instanceof Constructor)) {
        throw new TypeError("Cannot call a class as a function");
      }
    }

    function _defineProperties(target, props) {
      for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
      }
    }

    function _createClass(Constructor, protoProps, staticProps) {
      if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
    }

    /**
     * Entry-point for "Fragments" (sidebar pane) functionality.
     */
    var Fragments = /*#__PURE__*/function () {
      function Fragments(_ref) {
        var app = _ref.app,
            panel = _ref.panel;

        _classCallCheck(this, Fragments);

        this.Component = (0, _AppContext.Component)(app);
        this.title = panel.label;
      }

      _createClass(Fragments, [{
        key: "renderSidebar",
        value: function renderSidebar() {
          var Component = this.Component;
          return _react["default"].createElement(Component, null, _react["default"].createElement(_FragmentsSidebar["default"], {
            title: this.title
          }));
        }
      }]);

      return Fragments;
    }();

    exports["default"] = Fragments;
    //# sourceMappingURL=index.js.map
  }
});
//# sourceMappingURL=index.js.map

==> com.liferay.layout.content.page.editor.web-2.0.122.jar: META-INF/resources/page_editor/plugins/fragments-widgets/index.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.122/page_editor/plugins/fragments-widgets/index", ['module', 'exports', 'require', 'frontend-js-react-web$react', '../../core/AppContext', './components/FragmentsSidebar'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;

    var _react = _interopRequireDefault(require("frontend-js-react-web$react"));

    var _AppContext = require("../../core/AppContext");

    var _FragmentsSidebar = _interopRequireDefault(require("./components/FragmentsSidebar"));

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { default: obj };
    }

    function _classCallCheck(instance, Constructor) {
      if (!(instance instanceof Constructor)) {
        throw new TypeError("Cannot call a class as a function");
      }
    }

    function _defineProperties(target, props) {
      for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
      }
    }

    function _createClass(Constructor, protoProps, staticProps) {
      if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
    }

    /**
     * Entry-point for "Fragments" (sidebar pane) functionality.
     */
    var Fragments = /*#__PURE__*/function () {
      function Fragments(_ref) {
        var app = _ref.app,
            panel = _ref.panel;

        _classCallCheck(this, Fragments);

        this.Component = (0, _AppContext.Component)(app);
        this.title = panel.label;
      }

      _createClass(Fragments, [{
        key: "renderSidebar",
        value: function renderSidebar() {
          var Component = this.Component;
          return (/*#__PURE__*/_react.default.createElement(Component, null, /*#__PURE__*/_react.default.createElement(_FragmentsSidebar.default, {
              title: this.title
            }))
          );
        }
      }]);

      return Fragments;
    }();

    exports.default = Fragments;
    //# sourceMappingURL=index.js.map
  }
});
//# sourceMappingURL=index.js.map
